from dataclasses import dataclass, field
from ldap3 import Server, Connection, ALL

import logging

logger = logging.getLogger(__name__)


@dataclass
class Client:
    host: str
    port: int
    user: str
    password: str
    use_ssl: bool = False
    server: Server = field(init=False)
    connection: Connection = field(init=False)

    def __post_init__(self):
        """Initialise le serveur et la connexion LDAP."""
        self.server = Server(
            self.host, port=self.port, use_ssl=self.use_ssl, get_info=ALL
        )
        self.connection = Connection(
            self.server, user=self.user, password=self.password, auto_bind=True
        )
        logger.info("Connexion LDAP établie avec succès")

    def close(self):
        """Ferme la connexion LDAP."""
        logger.info("Fermeture de la connexion LDAP")
        self.connection.unbind()
