from dataclasses import dataclass, field
import datetime


@dataclass
class UO:
    """Classe représentant une UO dans l'annuaire LDAP"""

    cn: str
    ou: str
    supannCodeEntite: str
    description: str
    runUnivStrInfos: str
    supannCodeEntiteParent: str
    supannRefId: list[str]
    runUnivLastModified: datetime.datetime | None = field(default=None)

    def __post_init__(self):
        """Vérifie que les attributs requis sont présents"""

        self.supannRefId = (
            [self.supannRefId]
            if isinstance(self.supannRefId, str)
            else self.supannRefId
        )

    def to_gpuc(self) -> list[str]:
        """Récupère les valeurs de l'objet UO pour la création des données GPUC

        Returns:
            Liste pour la création des données GPUC
            - Code UO
            - Libellé UO
            - Code UO parent
            - UID responsable
        """
        return [
            self.supannCodeEntite,  # Code UO
            self.description,  # Libellé UO
            self.supannCodeEntiteParent,  # Code UO parent
            "",  # UID responsable
        ]
